Learn R Programming

FastJM (version 1.7.0)

Concordance: Concordance for joint models

Description

Concordance for joint models

Usage

Concordance(
  seed = 100,
  object,
  n.cv = 3,
  maxiter = 10000,
  initial.para = TRUE,
  ...
)

Value

A list containing:

n.cv

The number of cross-validation folds.

Concordance.cv

A list of fold-specific concordance estimates.

PI.cv

A list of fold-specific Cindex value for the estimated time-independent prognostic indexes across subjects.

CompetingRisk

Logical value indicating whether the fitted model accounts for competing risks.

seed

The random seed used for cross-validation.

Arguments

seed

A numeric value used to set the random seed for cross-validation. Default is 100.

object

A fitted object of class jmcs, JMMLSM, or mvjmcs.

n.cv

Number of cross-validation folds. Default is 3.

maxiter

Maximum number of EM iterations allowed when refitting the model within each cross-validation fold. Default is 10000.

initial.para

Logical value indicating whether initial parameter values are used when refitting the model. Default is TRUE.

...

Further arguments passed to model-specific methods.

See Also

jmcs, JMMLSM