View source: R/Concordancejmcs.R
| Concordancejmcs | R Documentation |
Concordance for joint models
Concordancejmcs(
seed = 100,
object,
opt = "nlminb",
n.cv = 3,
maxiter = 10000,
initial.optimizer = "BFGS",
initial.para = TRUE,
...
)
seed |
a numeric value of seed to be specified for cross validation. |
object |
object of class 'jmcs'. |
opt |
Optimization method to fit a linear mixed effects model, either nlminb (default) or optim. |
n.cv |
number of folds for cross validation. Default is 3. |
maxiter |
the maximum number of iterations of the EM algorithm that the function will perform. Default is 10000. |
initial.optimizer |
Method for numerical optimization to be used. Default is |
initial.para |
Initial guess of parameters for cross validation. Default is FALSE. |
... |
Further arguments passed to or from other methods. |
a list of matrices with conditional probabilities for subjects.
Shanpeng Li lishanpeng0913@ucla.edu
jmcs
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.