cdatah: Simulated competing risks data where event hazards depend on...

cdatahR Documentation

Simulated competing risks data where event hazards depend on within-subject variance

Description

The cdatah data frame has 200 rows and 6 columns.

Usage

data(cdatah)

Format

This data frame contains the following columns:

ID

patient identifier.

survtime

event time.

cmprsk

event indicator. 0 denotes censoring, 1 risk 1, and 2 risk 2.

var1

treatment indicator. 0 denotes the placebo group and 1 the treatment group.

var2

continuous variable.

var3

continuous variable.


FastJM documentation built on March 28, 2026, 5:07 p.m.