Learn R Programming

FastJM (version 1.7.0)

mvjmcs_control: Control Options for mvjmcs

Description

Control options for mvjmcs()

Usage

mvjmcs_control(
  maxiter = 10000,
  opt = c("nlminb", "optim"),
  tol = 0.005,
  verbose = FALSE,
  initial.para = NULL,
  cpu.cores = NULL
)

Value

A list of control parameters used by mvjmcs().

Arguments

maxiter

Maximum number of EM iterations. The default is 10000.

opt

Optimization method used to fit the initial mixed-effects models. Available options are "nlminb" and "optim". The default is "nlminb".

tol

Convergence tolerance. The default is 0.005.

verbose

Logical value indicating whether to print iteration details. The default is FALSE.

initial.para

Optional list of user-supplied initial parameter values for the EM algorithm. The default is NULL.

cpu.cores

Number of CPU cores used for parallel computation. The default is NULL, in which case the function uses its default computation strategy.

Details

Specifies convergence, initialization, optimizer, verbosity, and parallel computing settings for mvjmcs().