summary: Summaries of evaluation metrics for joint models

summaryR Documentation

Summaries of evaluation metrics for joint models

Description

Produce result summaries of a joint model fit.

Produce result summaries of a joint model fit.

Produce result summaries of a joint model fit.

Usage

## S3 method for class 'AUCJMMLSM'
summary(object, digits = 4, ...)

## S3 method for class 'ConcordanceJMMLSM'
summary(object, digits = 4, ...)

## S3 method for class 'Concordancejmcs'
summary(object, digits = 4, ...)

## S3 method for class 'DynPredAccjmcs'
summary(
  object,
  metric = c("AUC", "Cindex", "Brier", "MAE", "MAEQ"),
  digits = 4,
  ...
)

## S3 method for class 'JMMLSM'
summary(object, process = c("longitudinal", "survival"), digits = 4, ...)

## S3 method for class 'MAEQJMMLSM'
summary(object, digits = 3, ...)

## S3 method for class 'PEJMMLSM'
summary(object, error = c("MAE", "Brier"), ...)

## S3 method for class 'jmcs'
summary(object, process = c("Longitudinal", "Event"), digits = 4, ...)

## S3 method for class 'mvjmcs'
summary(object, process = c("Longitudinal", "Event"), digits = 4, ...)

Arguments

object

an object inheriting from class mvjmcs.

digits

the number of significant digits to use when printing. Default is 4.

...

further arguments passed to or from other methods.

metric

a list to indicate what metric to summarize

process

for which model (i.e., longitudinal model or survival model) to extract the estimated coefficients.

error

a character string that specifies the loss function.

Value

a list of matrices with conditional probabilities for subjects.

a list of matrices with conditional probabilities for subjects.

a list of matrices with conditional probabilities for subjects.

a summary of the list of matrices with conditional probabilities for subjects.

A table to summarize the model results.

a list of matrices with conditional probabilities for subjects.

a list of matrices with conditional probabilities for subjects.

A table to summarize the model results.

A table to summarize the model results.

Author(s)

Shanpeng Li lishanpeng0913@ucla.edu

See Also

JMMLSM, survfitJMMLSM

JMMLSM, survfitJMMLSM

jmcs, survfitjmcs

jmcs, survfitjmcs

JMMLSM

JMMLSM, survfitJMMLSM

JMMLSM, survfitJMMLSM

jmcs

mvjmcs


FastJM documentation built on March 28, 2026, 5:07 p.m.