vcov: Variance-covariance matrix of the estimated parameters for...

vcovR Documentation

Variance-covariance matrix of the estimated parameters for joint models

Description

Extract variance-covariance matrix for joint models.

Extract variance-covariance matrix for joint models.

Usage

## S3 method for class 'JMMLSM'
vcov(object, ...)

## S3 method for class 'jmcs'
vcov(object, ...)

Arguments

object

an object inheriting from class jmcs.

...

further arguments passed to or from other methods.

Value

a matrix of variance covariance of all parameter estimates.

a matrix of variance covariance of all parameter estimates.

Author(s)

Shanpeng Li lishanpeng0913@ucla.edu

See Also

JMMLSM

jmcs


FastJM documentation built on March 28, 2026, 5:07 p.m.