Concordance for joint models
Concordance(
seed = 100,
object,
n.cv = 3,
maxiter = 10000,
initial.para = TRUE,
...
)A list containing:
n.cvThe number of cross-validation folds.
Concordance.cvA list of fold-specific concordance estimates.
PI.cvA list of fold-specific Cindex value for the estimated time-independent prognostic indexes across subjects.
CompetingRiskLogical value indicating whether the fitted model accounts for competing risks.
seedThe random seed used for cross-validation.
A numeric value used to set the random seed for cross-validation.
Default is 100.
A fitted object of class jmcs, JMMLSM, or mvjmcs.
Number of cross-validation folds. Default is 3.
Maximum number of EM iterations allowed when refitting the
model within each cross-validation fold. Default is 10000.
Logical value indicating whether initial parameter values
are used when refitting the model. Default is TRUE.
Further arguments passed to model-specific methods.
jmcs, JMMLSM