Plot conditional probabilities for new subjects.
If CompetingRisk = FALSE, print the survival probabilities.
Otherwise, print the cumulative incidence probabilities for each failure type.
Plot conditional probabilities for new subjects.
If CompetingRisk = FALSE, print the survival probabilities.
Otherwise, print the cumulative incidence probabilities for each failure type.
Plot subject-specific conditional survival probabilities or cumulative
incidence probabilities from a survfitmvjmcs object. Longitudinal
observations for multiple biomarkers are stacked vertically, with the
predicted survival or cumulative incidence curve overlaid on each panel.
# S3 method for survfitJMMLSM
plot(
x,
include.y = FALSE,
xlab = NULL,
ylab = NULL,
xlim = NULL,
ylim.long = NULL,
ylim.surv = NULL,
...
)# S3 method for survfitjmcs
plot(
x,
include.y = FALSE,
xlab = NULL,
ylab = NULL,
xlim = NULL,
ylim.long = NULL,
ylim.surv = NULL,
...
)
# S3 method for survfitmvjmcs
plot(
x,
subject = NULL,
risk = 1,
include.y = TRUE,
xlab = NULL,
ylab = NULL,
xlim = NULL,
ylim.surv = NULL,
...
)
plots of conditional probabilities over different pre-specified time points for subjects. If single failure type, then survival probabilities will be returned. Otherwise, cumulative incidence probabilities for each failure type will be returned.
plots of conditional probabilities over different pre-specified time points for subjects. If single failure type, then survival probabilities will be returned. Otherwise, cumulative incidence probabilities for each failure type will be returned.
An object of class survfitmvjmcs.
Logical; retained for consistency with other plotting
methods. The current method always displays longitudinal biomarker panels.
Default is TRUE.
X axis label.
Y axis label.
X axis support.
Y axis support for the longitudinal outcome.
Y axis support for the event / survival probability.
Additional graphical arguments passed to the biomarker point plot.
Optional subject or subjects to plot. Can be a subject ID,
a numeric subject index, or a vector of IDs or indices. If NULL, all
subjects in x$Last.time are plotted. Default is NULL.
Failure type to plot when x$CompetingRisk = TRUE.
Default is 1.
Shanpeng Li lishanpeng0913@ucla.edu
survfitJMMLSM
survfitjmcs
survfitmvjmcs