| summary | R Documentation |
Produce result summaries of a joint model fit.
Produce result summaries of a joint model fit.
Produce result summaries of a joint model fit.
## S3 method for class 'AUCJMMLSM'
summary(object, digits = 4, ...)
## S3 method for class 'ConcordanceJMMLSM'
summary(object, digits = 4, ...)
## S3 method for class 'Concordancejmcs'
summary(object, digits = 4, ...)
## S3 method for class 'DynPredAccjmcs'
summary(
object,
metric = c("AUC", "Cindex", "Brier", "MAE", "MAEQ"),
digits = 4,
...
)
## S3 method for class 'JMMLSM'
summary(object, process = c("longitudinal", "survival"), digits = 4, ...)
## S3 method for class 'MAEQJMMLSM'
summary(object, digits = 3, ...)
## S3 method for class 'PEJMMLSM'
summary(object, error = c("MAE", "Brier"), ...)
## S3 method for class 'jmcs'
summary(object, process = c("Longitudinal", "Event"), digits = 4, ...)
## S3 method for class 'mvjmcs'
summary(object, process = c("Longitudinal", "Event"), digits = 4, ...)
object |
an object inheriting from class |
digits |
the number of significant digits to use when printing. Default is 4. |
... |
further arguments passed to or from other methods. |
metric |
a list to indicate what metric to summarize |
process |
for which model (i.e., longitudinal model or survival model) to extract the estimated coefficients. |
error |
a character string that specifies the loss function. |
a list of matrices with conditional probabilities for subjects.
a list of matrices with conditional probabilities for subjects.
a list of matrices with conditional probabilities for subjects.
a summary of the list of matrices with conditional probabilities for subjects.
A table to summarize the model results.
a list of matrices with conditional probabilities for subjects.
a list of matrices with conditional probabilities for subjects.
A table to summarize the model results.
A table to summarize the model results.
Shanpeng Li lishanpeng0913@ucla.edu
JMMLSM, survfitJMMLSM
JMMLSM, survfitJMMLSM
jmcs, survfitjmcs
jmcs, survfitjmcs
JMMLSM
JMMLSM, survfitJMMLSM
JMMLSM, survfitJMMLSM
jmcs
mvjmcs
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.