Produce result summaries of a joint model fit.
Produce result summaries of a joint model fit.
Produce result summaries of a joint model fit.
# S3 method for DynPredAcc
summary(
object,
metric = c("AUC", "Cindex", "Brier Score", "MAE", "MAEQ"),
digits = 4,
...
)# S3 method for JMMLSM
summary(object, process = c("longitudinal", "Event"), digits = 4, ...)
# S3 method for jmcs
summary(object, process = c("Longitudinal", "Event"), digits = 4, ...)
# S3 method for mvjmcs
summary(object, process = c("Longitudinal", "Event"), digits = 4, ...)
a summary of the list of matrices with conditional probabilities for subjects.
A table to summarize the model results.
A table to summarize the model results.
A table to summarize the model results.
an object inheriting from class mvjmcs.
a list to indicate what metric to summarize
the number of significant digits to use when printing. Default is 4.
further arguments passed to or from other methods.
for which model (i.e., longitudinal model or survival model) to extract the estimated coefficients.
JMMLSM
jmcs
mvjmcs