Learn R Programming

FastJM (version 1.7.0)

vcov: Variance-covariance matrix of the estimated parameters for joint models

Description

Extract variance-covariance matrix for joint models.

Extract variance-covariance matrix for joint models.

Extract variance-covariance matrix for joint models.

Usage

# S3 method for JMMLSM
vcov(object, ...)

# S3 method for jmcs vcov(object, ...)

# S3 method for mvjmcs vcov(object, ...)

Value

a matrix of variance covariance of all parameter estimates.

a matrix of variance covariance of all parameter estimates.

a matrix of variance covariance of all parameter estimates.

Arguments

object

an object inheriting from class mvjmcs.

...

further arguments passed to or from other methods.

Author

Shanpeng Li lishanpeng0913@ucla.edu

See Also

JMMLSM

jmcs

mvjmcs